.. _bibliography:

############
Bibliography
############

.. The bibliography is built from references contained within
   bibliography.bib. Add new references to bibliography.bib.

.. bibliography::
